library(tidyverse)

Data <- read_csv('./data/speakingTime-data.csv')

## checking all numbers that appear in the text
min(Data$Group_Size); max(Data$Group_Size)

length(unique(Data$Group_ID[Data$Institution == "S1"])) #B
length(unique(Data$Group_ID[Data$Institution == "S2"])) #S
length(unique(Data$pID[Data$Institution == "S1"]))
length(unique(Data$pID[Data$Institution == "S2"]))

min(Data$Age, na.rm = TRUE); max(Data$Age, na.rm = TRUE)
mean(Data$Age, na.rm = TRUE)

t.test(x = Data$Age[Data$Institution == "S1"],
       y = Data$Age[Data$Institution == "S2"],
       alternative = "two.sided")

sum(Data$English_Second_Language == "yes")/nrow(Data)

                                        # greater proportion of participants ESL at one than the other
chisq.test(table(Data$English_Second_Language, Data$Institution))

cor(Data$Planning_Phase_Vote_Total, Data$Gameplay_Phase_Vote_Total)

                                        # 61.7% of participants spoke at or less than the mean
f <- ecdf(Data$Total_Speaking_Time/1000); f(mean(Data$Total_Speaking_Time/1000))

                                        # 27 participants did not speak at all
Data %>% ungroup() %>% filter(Total_Speaking_Time == 0) %>% summarize(n())

                                        # one member with TST = 0 in x groups
Data %>% group_by(Group_ID) %>% filter(Total_Speaking_Time == 0) %>% summarize(n())

                                        # check ICC1 values
psych::statsBy(Data %>%
    ungroup() %>%
    mutate_at(vars(Gender, English_Second_Language, Participant_Is_Operator, Group_ID), as.factor) %>%
    mutate_at(vars(Gender, English_Second_Language, Participant_Is_Operator, Group_ID), as.integer) %>%
    select(
        Planning_Phase_Vote_Total, Total_Speaking_Time, Age, Gender, Intelligence,
        Game_Knowledge_Quiz, English_Second_Language, Conscientiousness, Agreeableness,
        Neuroticism, Openness, Extraversion, Participant_Is_Operator, Group_ID),
    group = 'Group_ID')$ICC1

                                        # check partial correlations
intel <- Data$Intelligence
gkq <- Data$Game_Knowledge_Quiz
esl <- Data$English_Second_Language
esl <- gsub("no", 0, esl); esl <- gsub("yes", 1, esl); esl <- as.integer(esl)
inst <- Data$Institution
inst <- gsub("B", 0L, inst); inst <- gsub("S", 1L, inst); inst <- as.integer(inst)
ppcor::pcor(data.frame(inst, intel, esl))$estimate
ppcor::pcor(data.frame(inst, gkq, esl))$estimate

                                        # was the distribution of females uniform across the groups
gender_prop <- Data %>%
    group_by(Group_ID) %>%
    summarize(n_female = sum(Gender == "female"), size = mean(Group_Size)) %>%
    mutate(p_female = n_female/size)
chisq.test(gender_prop$p_female)
summary(gender_prop$p_female)

1/.02568
1.152041/0.02568

                                        # consensus leader groups
Data %>%
    group_by(Group_ID) %>%
    filter(Planning_Phase_Vote_Total == max(Planning_Phase_Vote_Total),
           Planning_Phase_Vote_Total == Group_Size) %>%
    select(Group_ID, Planning_Phase_Vote_Total, Group_Size)

                                        # classification performance
Data <- Data %>%
    group_by(Group_ID) %>%
    mutate(Votes_Rank = dense_rank(desc(Planning_Phase_Vote_Total))) %>%
    mutate(TST_Rank = dense_rank(desc(Total_Speaking_Time)))

nrow(Data %>% filter(Votes_Rank == 1, TST_Rank == 1))/nrow(Data %>% filter(TST_Rank == 1))
nrow(Data %>% filter(Votes_Rank == 1 | Votes_Rank == 2, TST_Rank == 1))/nrow(Data %>% filter(TST_Rank == 1))

nrow(Data %>% filter(Votes_Rank == 1, TST_Rank == 1, Gender == 'female'))/nrow(Data %>% filter(TST_Rank == 1, Gender == 'female'))
nrow(Data %>% filter(Votes_Rank == 1, TST_Rank == 1, Gender == 'male'))/nrow(Data %>% filter(TST_Rank == 1, Gender == 'male'))

nrow(Data %>% filter(Votes_Rank == 1 | Votes_Rank == 2, TST_Rank == 1, Gender == 'female'))/nrow(Data %>% filter(TST_Rank == 1, Gender == 'female'))
nrow(Data %>% filter(Votes_Rank == 1 | Votes_Rank == 2, TST_Rank == 1, Gender == 'male'))/nrow(Data %>% filter(TST_Rank == 1, Gender == 'male'))

                                        # what are the percent differences between coefficients?
l_tst <- c(0.026, 0.004)
l_gender <- c(1.166, 0.187)
r_tst <- c(0.029, 0.005)
r_gender <- c(1.075, 0.224)

find_pdiff <- function(a, b) {
    return (b - a)/a
}

sum(Data$Gender == "male")
sum(Data$Gender == "female")
