import os
import numpy as np
import pandas as pd
import xml.etree.ElementTree as ET

def collect_speaking_time(participant, root, timeOrder, totalSpeakingTime, numberSpeakingTurns, speechVectors):
    """
    Calculate total speaking time (TST) and number of speaking turns (NST) for each participant.

    TST is the sum of the duration of all recorded vocalizations.

    NST is the count of all recorded vocalizations.
    """
    i = participant.get('TIER_ID')[4:]
    speechVector = []
    for u in participant.iter('ALIGNABLE_ANNOTATION'):
        ts1 = u.get('TIME_SLOT_REF1')
        ts2 = u.get('TIME_SLOT_REF2')
        begin = None
        end = None
        for ts in timeOrder.iter('TIME_SLOT'):
            if ts.get('TIME_SLOT_ID') == ts1:
                begin = int(ts.get('TIME_VALUE'))
        for ts in timeOrder.iter('TIME_SLOT'):
            if ts.get('TIME_SLOT_ID') == ts2:
                end = int(ts.get('TIME_VALUE'))
        speechVector.append(end - begin)
    speechVectors[sID + i] = speechVector
    totalSpeakingTime[sID + i] = sum(speechVector)
    numberSpeakingTurns[sID + i] = len(speechVector)

survey_data = pd.read_csv('./data/speakingTime-data.csv')
survey_data = survey_data.set_index('pID')
out_data = []

path = './data/diarizations/'
filenames = os.listdir(path)
for filename in filenames:
    sID = filename.replace('pl.eaf', '')
    group_data = survey_data[survey_data['Group_ID'].isin([sID])][['Planning_Phase_Vote_Total', 'Simulation']]
    
    pIDs = group_data.index.values

    tree = ET.parse(path + filename)
    root = tree.getroot()
    timeOrder = root.find('TIME_ORDER')
    startTime = timeOrder[1].get('TIME_VALUE')
    participants = root.findall('TIER')[2:]

    totalSpeakingTime = {}
    numberSpeakingTurns = {}
    speechVectors = {}

    for participant in participants:
        pID = sID + participant.get('TIER_ID')[4:]
        if pID not in pIDs:
            continue
        collect_speaking_time(participant, root, timeOrder, totalSpeakingTime, numberSpeakingTurns, speechVectors)

    group_data['tst'] = pd.Series(totalSpeakingTime)
    group_data['nst'] = pd.Series(numberSpeakingTurns)

    out_data.append(group_data)

out_data = pd.concat(out_data)
out_data.to_csv('./data/out_data.csv')
